@@ -20,11 +20,14 @@ from .bobcat1 import Bobcat1
 from .bugsat1 import Bugsat1
 from .cape1 import Cape1
 from .cas4 import Cas4
+from .cas9 import Cas9
 from .chomptt import Chomptt
 from .csim import Csim
 from .cubebel1 import Cubebel1
 from .cubesatsim import Cubesatsim
+from .cute import Cute
 from .delfin3xt import Delfin3xt
+from .delfipq import Delfipq
 from .dhabisat import Dhabisat
 from .diy1 import Diy1
 from .duchifat3 import Duchifat3
@@ -82,11 +85,14 @@ __all__ = [
     'Bugsat1',
     'Cape1',
     'Cas4',
+    'Cas9',
     'Chomptt',
     'Cubebel1',
     'Cubesatsim',
+    'Cute',
     'Csim',
     'Delfin3xt',
+    'Delfipq',
     'Dhabisat',
     'Diy1',
     'Duchifat3',
