@@ -10,8 +10,8 @@ if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
 
 class Bobcat1(KaitaiStruct):
     """:field data: frame.cspheader.data
-    :field callsign: frame.data.callsign
-    :field bobcat1: frame.data.bobcat1
+    :field callsign: frame.data.callsigns.callsign
+    :field bobcat1: frame.data.callsigns.bobcat1
     :field bat_v: frame.data.bat_v
     :field bat_i_out: frame.data.bat_i_out
     :field bat_i_in: frame.data.bat_i_in
@@ -39,8 +39,8 @@ class Bobcat1(KaitaiStruct):
     :field checksum: frame.hk_frame.a3200_hktable0.checksum
     :field a3200_hktable0_timestamp: frame.hk_frame.a3200_hktable0.timestamp
     :field source: frame.hk_frame.a3200_hktable0.source
-    :field callsign: frame.hk_frame.callsign
-    :field bobcat1: frame.hk_frame.bobcat1
+    :field callsign: frame.hk_frame.callsigns.callsign
+    :field bobcat1: frame.hk_frame.callsigns.bobcat1
     :field bat_v: frame.hk_frame.bat_v
     :field bat_i_in: frame.hk_frame.bat_i_in
     :field bat_i_out: frame.hk_frame.bat_i_out
@@ -94,8 +94,8 @@ class Bobcat1(KaitaiStruct):
     :field a3200_hktable_17_1_checksum: frame.extra_frame.a3200_hktable_17_1.checksum
     :field a3200_hktable_17_1_timestamp: frame.extra_frame.a3200_hktable_17_1.timestamp
     :field a3200_hktable_17_1_source: frame.extra_frame.a3200_hktable_17_1.source
-    :field callsign: frame.extra_frame.callsign
-    :field bobcat1: frame.extra_frame.bobcat1
+    :field callsign: frame.extra_frame.callsigns.callsign
+    :field bobcat1: frame.extra_frame.callsigns.bobcat1
     :field coll_running: frame.extra_frame.coll_running
     :field lat: frame.extra_frame.lat
     :field long: frame.extra_frame.long
@@ -175,12 +175,7 @@ class Bobcat1(KaitaiStruct):
 
         def _read(self):
             self.a3200_hktable_17_1 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
-            self.callsign = self._io.read_bytes(6)
-            if not self.callsign == b"\x57\x38\x50\x5A\x53\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x57\x38\x50\x5A\x53\x00", self.callsign, self._io, u"/types/extra_data/seq/1")
-            self.bobcat1 = self._io.read_bytes(9)
-            if not self.bobcat1 == b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00", self.bobcat1, self._io, u"/types/extra_data/seq/2")
+            self.callsigns = Bobcat1.Callsigns(self._io, self, self._root)
             self.coll_running = self._io.read_u1()
             self.lat = self._io.read_f4be()
             self.long = self._io.read_f4be()
@@ -204,12 +199,7 @@ class Bobcat1(KaitaiStruct):
 
         def _read(self):
             self.a3200_hktable0 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
-            self.callsign = self._io.read_bytes(6)
-            if not self.callsign == b"\x57\x38\x50\x5A\x53\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x57\x38\x50\x5A\x53\x00", self.callsign, self._io, u"/types/hk_data/seq/1")
-            self.bobcat1 = self._io.read_bytes(9)
-            if not self.bobcat1 == b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00", self.bobcat1, self._io, u"/types/hk_data/seq/2")
+            self.callsigns = Bobcat1.Callsigns(self._io, self, self._root)
             self.bat_v = self._io.read_u2be()
             self.bat_i_in = self._io.read_u2be()
             self.bat_i_out = self._io.read_u2be()
@@ -295,12 +285,7 @@ class Bobcat1(KaitaiStruct):
             self._read()
 
         def _read(self):
-            self.callsign = self._io.read_bytes(6)
-            if not self.callsign == b"\x57\x38\x50\x5A\x53\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x57\x38\x50\x5A\x53\x00", self.callsign, self._io, u"/types/basic/seq/0")
-            self.bobcat1 = self._io.read_bytes(9)
-            if not self.bobcat1 == b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00":
-                raise kaitaistruct.ValidationNotEqualError(b"\x42\x4F\x42\x43\x41\x54\x2D\x31\x00", self.bobcat1, self._io, u"/types/basic/seq/1")
+            self.callsigns = Bobcat1.Callsigns(self._io, self, self._root)
             self.bat_v = self._io.read_u2be()
             self.bat_i_out = self._io.read_u2be()
             self.bat_i_in = self._io.read_u2be()
@@ -323,6 +308,22 @@ class Bobcat1(KaitaiStruct):
             self.timestamp = self._io.read_u4be()
 
 
+    class Callsigns(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.callsign = (self._io.read_bytes_term(0, False, True, True)).decode(u"ASCII")
+            if not self.callsign == u"W8PZS":
+                raise kaitaistruct.ValidationNotEqualError(u"W8PZS", self.callsign, self._io, u"/types/callsigns/seq/0")
+            self.bobcat1 = (self._io.read_bytes_term(0, False, True, True)).decode(u"ASCII")
+            if not self.bobcat1 == u"BOBCAT-1":
+                raise kaitaistruct.ValidationNotEqualError(u"BOBCAT-1", self.bobcat1, self._io, u"/types/callsigns/seq/1")
+
+
     class Bc1BasicFrame(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
