@@ -3,10 +3,13 @@ SatNOGS Processor subpackage initialization
 """
 from __future__ import absolute_import, division, print_function
 
+from .b64decode import B64decode
 from .b64encode import B64encode
 from .b85decode import B85decode
 from .b85encode import B85encode
 from .elfin_pp import ElfinPp
 from .scrambler import Scrambler
 
-__all__ = ['ElfinPp', 'B85encode', 'B85decode', 'Scrambler', 'B64encode']
+__all__ = [
+    'ElfinPp', 'B85encode', 'B85decode', 'Scrambler', 'B64encode', 'B64decode'
+]
